#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-85QAHqGSfpT4cfaq8WJvi1
key:                  doctest-parallel-0.3.1-85QAHqGSfpT4cfaq8WJvi1
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  068672eb0ad9dff3d553193e21497bfd
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-85QAHqGSfpT4cfaq8WJvi1
depends:
    Cabal-3.10.3.0 Glob-0.10.2-B4dWofglFwp3mtUB4xIvnb base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ process-1.6.19.0
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-2IveibkvPuoEOMXZfRFYqA-spectests-modules

key:
    doctest-parallel-0.3.1-2IveibkvPuoEOMXZfRFYqA-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  8df3a08f114e74c7bdbcbd4a7fffd912
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-2IveibkvPuoEOMXZfRFYqA-spectests-modules

depends:
    base-4.18.2.1 doctest-parallel-0.3.1-85QAHqGSfpT4cfaq8WJvi1
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

